@@ -25,6 +25,11 @@ import aws_cdk.aws_sqs
 import aws_cdk.aws_stepfunctions
 import aws_cdk.core
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-stepfunctions-tasks", "1.33.0", __name__[0:-6], "aws-stepfunctions-tasks@1.33.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
